@@ -407,6 +407,7 @@
 \\majorSevenSymbol
 \\major
 \\maininput
+\\magnifyMusic
 \\magnify
 \\lyricsto
 \\lyrics
@@ -419,7 +420,7 @@
 \\longfermata
 \\longa
 \\locrian
-\\localKeySignature
+\\localAlterations
 \\lineprall
 \\linea
 \\line
@@ -445,6 +446,7 @@
 \\keepWithTag
 \\keepAliveInterfaces
 \\justify-string
+\\justify-line
 \\justify-field
 \\justify
 \\justified-lines
